ExtrasCountry class
Constructors
-
ExtrasCountry({List<
PurpleRegion> ? regions, int? id, String? name, String? code, String? continent}) -
ExtrasCountry.fromMap(Map<
String, dynamic> json) -
factory
Properties
- code ↔ String?
-
getter/setter pair
- continent ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
-
regions
↔ List<
PurpleRegion> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited