FluffyRegion class
Constructors
-
FluffyRegion({int? id, String? name, String? code, bool? active, bool? singlePricing, bool? freeShipping, bool? allowsPod, dynamic baseCost, dynamic handlingCost, dynamic costPerMetric, String? costMetric, dynamic durationMin, dynamic durationMax, String? durationMetric, List<
LocalArea> ? localAreas}) -
FluffyRegion.fromMap(Map<
String, dynamic> json) -
factory
Properties
- active ↔ bool?
-
getter/setter pair
- allowsPod ↔ bool?
-
getter/setter pair
- baseCost ↔ dynamic
-
getter/setter pair
- code ↔ String?
-
getter/setter pair
- costMetric ↔ String?
-
getter/setter pair
- costPerMetric ↔ dynamic
-
getter/setter pair
- durationMax ↔ dynamic
-
getter/setter pair
- durationMetric ↔ String?
-
getter/setter pair
- durationMin ↔ dynamic
-
getter/setter pair
- freeShipping ↔ bool?
-
getter/setter pair
- handlingCost ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pair
-
localAreas
↔ List<
LocalArea> ? -
getter/setter pair
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singlePricing ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited