HomeGrid class
Constructors
- HomeGrid({dynamic totalItem, String? btnBgColor, bool? showBtn, dynamic titleClass, String? title, dynamic subtitleClass, dynamic btnStyles, dynamic prodTitleClass, dynamic subtitleStyles, String? productPriceTextColor, dynamic prodPriceClass, String? sectionType, int? id, String? btnText, String? subtitleColor, String? titleColor, HomeGridCollection? collection, dynamic prodTitleStyles, String? btnTextColor, dynamic prodPriceStyles, bool? showSubtitle, bool? showTitle, String? subtitle, dynamic titleStyles, dynamic productTitleColor, int? position, dynamic showRandomItems, dynamic btnClass})
-
HomeGrid.fromMap(Map<
String, dynamic> json) -
factory
Properties
- btnBgColor ↔ String?
-
getter/setter pair
- btnClass ↔ dynamic
-
getter/setter pair
- btnStyles ↔ dynamic
-
getter/setter pair
- btnText ↔ String?
-
getter/setter pair
- btnTextColor ↔ String?
-
getter/setter pair
- collection ↔ HomeGridCollection?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pair
- position ↔ int?
-
getter/setter pair
- prodPriceClass ↔ dynamic
-
getter/setter pair
- prodPriceStyles ↔ dynamic
-
getter/setter pair
- prodTitleClass ↔ dynamic
-
getter/setter pair
- prodTitleStyles ↔ dynamic
-
getter/setter pair
- productPriceTextColor ↔ String?
-
getter/setter pair
- productTitleColor ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionType ↔ String?
-
getter/setter pair
- showBtn ↔ bool?
-
getter/setter pair
- showRandomItems ↔ dynamic
-
getter/setter pair
- showSubtitle ↔ bool?
-
getter/setter pair
- showTitle ↔ bool?
-
getter/setter pair
- subtitle ↔ String?
-
getter/setter pair
- subtitleClass ↔ dynamic
-
getter/setter pair
- subtitleColor ↔ String?
-
getter/setter pair
- subtitleStyles ↔ dynamic
-
getter/setter pair
- title ↔ String?
-
getter/setter pair
- titleClass ↔ dynamic
-
getter/setter pair
- titleColor ↔ String?
-
getter/setter pair
- titleStyles ↔ dynamic
-
getter/setter pair
- totalItem ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited