HomeGridCollection class

Constructors

HomeGridCollection({dynamic thumbnail, dynamic code, String? name, dynamic baseUrl, dynamic bannerKey, int? id})
HomeGridCollection.fromMap(Map<String, dynamic> json)
factory

Properties

bannerKey ↔ dynamic
getter/setter pair
baseUrl ↔ dynamic
getter/setter pair
code ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited