Info class

Constructors

Info({List<Category>? categories, List<Brand>? brands, List<CollectionElement>? collections, List? outlets, List<Slider>? sliders, int? id, String? name, String? description, String? currencyCode, dynamic currencyName, String? subDomain, String? mode, String? address, double? vatPercent, dynamic baseUrl, dynamic logoKey, bool? applyVat, String? whatsappNumber, String? twitterUrl, dynamic shortUrl, String? facebookUrl, String? brandColor, String? instagramHandle, String? youtubeUrl, dynamic thumbnail, HomeGrid? homeGrid, List<PickupLocation>? pickupLocations, List<ShippingService>? shippingServices, List<PaymentGateway>? paymentGateways})
Info.fromMap(Map<String, dynamic> json)
factory

Properties

address String?
getter/setter pair
applyVat bool?
getter/setter pair
baseUrl ↔ dynamic
getter/setter pair
brandColor String?
getter/setter pair
brands List<Brand>?
getter/setter pair
categories List<Category>?
getter/setter pair
collections List<CollectionElement>?
getter/setter pair
currencyCode String?
getter/setter pair
currencyName ↔ dynamic
getter/setter pair
description String?
getter/setter pair
facebookUrl String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
homeGrid HomeGrid?
getter/setter pair
id int?
getter/setter pair
instagramHandle String?
getter/setter pair
logoKey ↔ dynamic
getter/setter pair
mode String?
getter/setter pair
name String?
getter/setter pair
outlets List?
getter/setter pair
paymentGateways List<PaymentGateway>?
getter/setter pair
pickupLocations List<PickupLocation>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingServices List<ShippingService>?
getter/setter pair
shortUrl ↔ dynamic
getter/setter pair
sliders List<Slider>?
getter/setter pair
subDomain String?
getter/setter pair
thumbnail ↔ dynamic
getter/setter pair
twitterUrl String?
getter/setter pair
vatPercent double?
getter/setter pair
whatsappNumber String?
getter/setter pair
youtubeUrl String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited