PickupLocation class

Constructors

PickupLocation({String? street2, String? city, String? street1, int? regionId, int? id, int? countryId, dynamic googlePlaceId, String? name, int? status})
PickupLocation.fromMap(Map<String, dynamic> json)
factory

Properties

city String?
getter/setter pair
countryId int?
getter/setter pair
googlePlaceId ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
name String?
getter/setter pair
regionId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
getter/setter pair
street1 String?
getter/setter pair
street2 String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited