ShippingServiceCountry class

Constructors

ShippingServiceCountry({int? id, String? name, String? code, List<FluffyRegion>? regions})
ShippingServiceCountry.fromMap(Map<String, dynamic> json)
factory

Properties

code String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
name String?
getter/setter pair
regions List<FluffyRegion>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited